@@ -1,8 +1,8 @@
 package HTML::Template::Compiled;
-# $Id: Compiled.pm,v 1.298 2006/11/20 19:07:20 tinita Exp $
+# $Id: Compiled.pm,v 1.302 2007/02/11 14:35:33 tinita Exp $
 # doesn't work with make tardist
 #our $VERSION = ($version_pod =~ m/^\$VERSION = "(\d+(?:\.\d+)+)"/m) ? $1 : "0.01";
-our $VERSION = "0.83";
+our $VERSION = "0.84";
 use Data::Dumper;
 BEGIN {
 use constant D => $ENV{HTC_DEBUG} || 0;
@@ -22,6 +22,8 @@ eval {
     require HTML::Entities;
     require URI::Escape;
 };
+use base 'Exporter';
+our @EXPORT_OK = qw(&HTC);
 use HTML::Template::Compiled::Parser qw(
     $CASE_SENSITIVE_DEFAULT $NEW_CHECK
     $DEBUG_DEFAULT $SEARCHPATH
@@ -48,6 +50,7 @@ BEGIN {
           debug perl out_fh default_escape
           filter formatter
           globalstack use_query parser compiler includes
+          plugins
         )
     );
 
@@ -62,6 +65,9 @@ BEGIN {
     }
 }
 
+# tired of typing?
+sub HTC { __PACKAGE__->new(@_) }
+
 sub new {
     my ( $class, %args ) = @_;
     D && $class->log("new()");
@@ -531,6 +537,8 @@ sub add_file_cache {
     #$includes_to_string =~ s/\$includes = //;
     my $search_path = $self->get_search_path || 0;
     my $gl = $self->get_global_vars;
+    my $plugins = $self->get_plugins;
+    my $plugin_dump = Data::Dumper->Dump([\@$plugins], ['plugin_dump']);
     my $file_args = $isScalar
       ? <<"EOM"
         scalarref => $isScalar,
@@ -543,6 +551,8 @@ EOM
     package HTML::Template::Compiled;
 # file date $lmtime
 # last checked date $lchecked
+# @$plugins
+my $plugin_dump;
 my $query_info;
 my $parser;
 my $includes_to_string;
@@ -569,6 +579,7 @@ $file_args
     global_vars => $gl,
     includes => \$includes,
     search_path_on_include => $search_path,
+    plugin => \$plugin_dump,
     # TODO
     # dumper => ...
     # template subroutine
@@ -727,12 +738,16 @@ sub init {
         $parser = $self->parser_class->new(
             tagstyle => $tagstyle,
         );
+        $parser->set_perl($defaults{use_perl});
     }
+    $args{parser} = ${$args{parser}} if ref $args{parser} eq 'REF';
     if (UNIVERSAL::isa($args{parser}, 'HTML::Template::Compiled::Parser')) {
         $parser = $args{parser};
     }
-    $parser ||= $self->parser_class->default();
-    $parser->set_perl($defaults{use_perl});
+    unless ($parser) {
+        $parser ||= $self->parser_class->default();
+        $parser->set_perl($defaults{use_perl});
+    }
     if ($defaults{use_perl}) {
         $parser->add_tagnames({
             HTML::Template::Compiled::Token::OPENING_TAG() => {
@@ -744,10 +759,8 @@ sub init {
     my $compiler = $self->compiler_class->new;
     $self->set_compiler($compiler);
     if ($defaults{plugin}) {
-        for my $plug (ref $defaults{plugin} eq 'ARRAY'
-            ? @{ $defaults{plugin} }
-            : $defaults{plugin}
-        ) {
+        my @plugins = ref $defaults{plugin} eq 'ARRAY' ? @{ $defaults{plugin} } : $defaults{plugin};;
+        for my $plug (@plugins) {
             if ($plug =~ m/^::/) {
                 $plug = "HTML::Template::Compiled::Plugin$plug";
             }
@@ -766,6 +779,7 @@ sub init {
                 $compiler->set_tags($tags);
             }
         }
+        $self->set_plugins(\@plugins);
     }
 }
 
@@ -954,6 +968,7 @@ sub new_from_object {
     $new->set_path($path);
     $new->set_perl(undef);
     if (my $cached = $new->from_cache) {
+        $cached->init_includes;
         return $cached
     }
     $new = $new->from_scratch;
@@ -1173,6 +1188,9 @@ sub import {
         $class->SearchPathOnInclude(1);
         $class->UseQuery(0);
     }
+    if (exists $args{short}) {
+        __PACKAGE__->export_to_level(1, scalar caller(), 'HTC');
+    }
 }
 
 sub ExpireTime {
@@ -1242,7 +1260,7 @@ HTML::Template::Compiled - Template System Compiles HTML::Template files to Perl
 
 =head1 VERSION
 
-$VERSION = "0.83"
+$VERSION = "0.84"
 
 =cut
 
